peek_count_lines: number of lines of a file

View source: R/funs.R

peek_count_linesR Documentation

number of lines of a file

Description

return the number of lines found in a file. Operation is counting the number of new line symbols in the file.

Usage

peek_count_lines(path, with_eof = FALSE)

Arguments

path

file path

with_eof

count the end of file as a new line.

Value

number of lines as an integer

Examples

f <- system.file(package = "fpeek",
  "datafiles", "test-tab.csv")
peek_count_lines(f)

fpeek documentation built on April 2, 2026, 5:07 p.m.