| peek_tail | R Documentation |
print the last n lines
of a file.
peek_tail(path, n = 10, intern = FALSE)
path |
file path |
n |
number of lines to print |
intern |
a logical which indicates whether to capture the output as an R character vector or to print the output in the R console. |
f <- system.file(package = "fpeek",
"datafiles", "test-tab.csv")
peek_tail(f, n = 4)
peek_tail(f, n = 4, intern = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.